diff -u easytag-2.1.4/debian/changelog easytag-2.1.4/debian/changelog
--- easytag-2.1.4/debian/changelog
+++ easytag-2.1.4/debian/changelog
@@ -1,3 +1,18 @@
+easytag (2.1.4-1.1) unstable; urgency=low
+
+  * Non-maintainer upload.
+  * Warn user when ogg vorbis tags will be lost, fix handling of multiple same
+    ogg vorbis tags (Closes: #460247).
+  * Fix lintian warnings:
+    - Add watch file.
+    - Install icon for menu file (Closes: #477456).
+    - Fix section in menu file.
+    - Drop version from NAME section of man page to `apropos' and `whatis'
+      happy.
+    - Include copyright information in debian/copyright.
+
+ -- Michal Čihař <nijel@debian.org>  Mon, 08 Sep 2008 21:44:11 +0200
+
 easytag (2.1.4-1) unstable; urgency=low
 
   * New upstream version
only in patch2:
unchanged:
--- easytag-2.1.4.orig/src/ogg_tag.c
+++ easytag-2.1.4/src/ogg_tag.c
@@ -271,6 +271,8 @@
     if ( (string = vorbis_comment_query(vc,"DATE",0)) != NULL && g_utf8_strlen(string, -1) > 0 )
     {
         FileTag->year = g_strdup(string);
+	if(g_utf8_strlen(FileTag->year, -1) > 4)
+		Log_Print(LOG_ERROR,_("Warning in %s :- Year of album %s seems to be invalid. The information will be lost while saving Tags."),filename_utf8,FileTag->year);
     }
 
     /*************************
@@ -564,6 +566,23 @@
 }
 
 
+static gboolean Ogg_Write_DelimeteredTag(vorbis_comment *vc,const gchar *tag,gchar *values){
+	gchar **strings = g_strsplit(values,MULTIFIELD_SEPARATOR,255);
+	unsigned int i=0;
+
+	for(i=0;i<g_strv_length(strings);i++)
+	{
+		if(strlen(strings[i])>0)
+		{
+        		char *string = g_strconcat(tag,strings[i],NULL);
+			vorbis_comment_add(vc,string);
+			g_free(string);
+		}
+	}
+        g_strfreev(strings);
+	return TRUE;
+}
+
 
 gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
 {
@@ -646,9 +665,7 @@
      *********/
     if ( FileTag->title )
     {
-        string = g_strconcat("TITLE=",FileTag->title,NULL);
-        vorbis_comment_add(vc,string);
-        g_free(string);
+	Ogg_Write_DelimeteredTag(vc,"TITLE=",FileTag->title);
     }
 
     /**********
@@ -656,9 +673,7 @@
      **********/
     if ( FileTag->artist )
     {
-        string = g_strconcat("ARTIST=",FileTag->artist,NULL);
-        vorbis_comment_add(vc,string);
-        g_free(string);
+	Ogg_Write_DelimeteredTag(vc,"ARTIST=",FileTag->artist);
     }
 
     /*********
@@ -666,9 +681,7 @@
      *********/
     if ( FileTag->album )
     {
-        string = g_strconcat("ALBUM=",FileTag->album,NULL);
-        vorbis_comment_add(vc,string);
-        g_free(string);
+	Ogg_Write_DelimeteredTag(vc,"ALBUM=",FileTag->album);
     }
 
     /***************
@@ -712,9 +725,7 @@
      *********/
     if ( FileTag->genre )
     {
-        string = g_strconcat("GENRE=",FileTag->genre,NULL);
-        vorbis_comment_add(vc,string);
-        g_free(string);
+	Ogg_Write_DelimeteredTag(vc,"GENRE=",FileTag->genre);
     }
 
     /***********
@@ -724,21 +735,17 @@
     if ( FileTag->comment )
     {
         // Format of new specification
-        string = g_strconcat("DESCRIPTION=",FileTag->comment,NULL);
-        vorbis_comment_add(vc,string);
-        g_free(string);
+	Ogg_Write_DelimeteredTag(vc,"DESCRIPTION=",FileTag->comment);
+
 
         // Format used in winamp plugin
-        string = g_strconcat("COMMENT=",FileTag->comment,NULL);
-        vorbis_comment_add(vc,string);
-        g_free(string);
+	Ogg_Write_DelimeteredTag(vc,"COMMENT=",FileTag->comment);
+
 
         if (OGG_TAG_WRITE_XMMS_COMMENT)
         {
             // Format used into xmms-1.2.5
-            string = g_strconcat("=",FileTag->comment,NULL);
-            vorbis_comment_add(vc,string);
-            g_free(string);
+		Ogg_Write_DelimeteredTag(vc,"=",FileTag->comment);
         }
     }
 
@@ -747,9 +754,7 @@
      ************/
     if ( FileTag->composer )
     {
-        string = g_strconcat("COMPOSER=",FileTag->composer,NULL);
-        vorbis_comment_add(vc,string);
-        g_free(string);
+	Ogg_Write_DelimeteredTag(vc,"COMPOSER=",FileTag->composer);
     }
 
     /*******************
@@ -757,9 +762,7 @@
      *******************/
     if ( FileTag->orig_artist )
     {
-        string = g_strconcat("PERFORMER=",FileTag->orig_artist,NULL);
-        vorbis_comment_add(vc,string);
-        g_free(string);
+	Ogg_Write_DelimeteredTag(vc,"PERFORMER=",FileTag->orig_artist);
     }
 
     /*************
only in patch2:
unchanged:
--- easytag-2.1.4.orig/src/misc.c
+++ easytag-2.1.4/src/misc.c
@@ -463,7 +463,7 @@
         /* Get the current date */
         memcpy(&t0, localtime(&t), sizeof(struct tm));
         /* Put the current year in 'current_year' tab */
-        sprintf(current_year,"%d",1900+t0.tm_year);
+        sprintf(current_year,"%04d",1900+t0.tm_year);
 
         tmp = &current_year[4-strlen(year)];
         if ( atoi(year) <= atoi(tmp) )
only in patch2:
unchanged:
--- easytag-2.1.4.orig/debian/copyright
+++ easytag-2.1.4/debian/copyright
@@ -5,7 +5,22 @@
 
 Upstream Author: Jerome Couderc <easytag@gmail.com>
 
-Copyright:
+Copyright: 
 
-This program is copyright under the GNU Public License (GPL), a copy
-of which may be found in /usr/share/common-licenses/GPL
+Copyright (C) 2000-2003  Jerome Couderc <easytag@gmail.com>
+
+    This package is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License version 2 as 
+    published by the Free Software Foundation. 
+
+    This package is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+ 
+    You should have received a copy of the GNU General Public License
+    along with this package; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+
+On Debian systems, the complete text of the GNU General
+Public License can be found in `/usr/share/common-licenses/GPL-2'.
only in patch2:
unchanged:
--- easytag-2.1.4.orig/debian/menu
+++ easytag-2.1.4/debian/menu
@@ -1,5 +1,5 @@
 ?package(easytag):needs="X11" \
-	section="Apps/Sound" \
+	section="Applications/Sound" \
 	title="easytag" \
 	command="/usr/bin/easytag" \
 	icon="/usr/share/pixmaps/easytag.xpm"
only in patch2:
unchanged:
--- easytag-2.1.4.orig/debian/easytag.xpm
+++ easytag-2.1.4/debian/easytag.xpm
@@ -1,360 +1,209 @@
 /* XPM */
-static char * easytag_32x32_xpm[] = {
-"32 32 325 2",
-"  	c #FFFFFF",
-". 	c #FFFFFE",
-"+ 	c #FFFDF4",
-"@ 	c #FFFBE9",
-"# 	c #FFF8DD",
-"$ 	c #FFF6D1",
-"% 	c #FFF4C6",
-"& 	c #FFF1BA",
-"* 	c #FFEEA6",
-"= 	c #FFF6D0",
-"- 	c #FFFEFC",
-"; 	c #FFFCEF",
-"> 	c #FFF9E2",
-", 	c #FFF7D7",
-"' 	c #FFF5CB",
-") 	c #FFF2BF",
-"! 	c #FFF0B0",
-"~ 	c #FEED9E",
-"{ 	c #FEEA8E",
-"] 	c #FEE87F",
-"^ 	c #FEE674",
-"/ 	c #FEE369",
-"( 	c #FEE161",
-"_ 	c #FDE15D",
-": 	c #FEE25F",
-"< 	c #FDE15B",
-"[ 	c #FEE35B",
-"} 	c #FEE45A",
-"| 	c #FDE557",
-"1 	c #FDE652",
-"2 	c #FEE64D",
-"3 	c #FDE547",
-"4 	c #FEE745",
-"5 	c #FEE676",
-"6 	c #FFF8DA",
-"7 	c #FDE465",
-"8 	c #FEE463",
-"9 	c #FDE360",
-"0 	c #FEE45E",
-"a 	c #FDE660",
-"b 	c #FCE256",
-"c 	c #FCE558",
-"d 	c #FCEB59",
-"e 	c #FCEB53",
-"f 	c #FCED52",
-"g 	c #FCEE52",
-"h 	c #FCF052",
-"i 	c #FCF152",
-"j 	c #FBF251",
-"k 	c #FCF350",
-"l 	c #FDEC4D",
-"m 	c #FDE74C",
-"n 	c #FCF14D",
-"o 	c #FCF14B",
-"p 	c #FDF04A",
-"q 	c #FDF049",
-"r 	c #FDEF48",
-"s 	c #FDEF46",
-"t 	c #FDEE45",
-"u 	c #FEED44",
-"v 	c #FEED43",
-"w 	c #FEE15C",
-"x 	c #FFF2BC",
-"y 	c #FAEE5C",
-"z 	c #F9FB62",
-"A 	c #F9FA61",
-"B 	c #F9FA60",
-"C 	c #FAF95F",
-"D 	c #FAF85D",
-"E 	c #FCED55",
-"F 	c #FCED54",
-"G 	c #FAF75A",
-"H 	c #FBF658",
-"I 	c #FBF657",
-"J 	c #FBF556",
-"K 	c #FBF555",
-"L 	c #FBF453",
-"M 	c #FBF452",
-"N 	c #FCF351",
-"O 	c #FCEF4E",
-"P 	c #FEE44B",
-"Q 	c #FCF14C",
-"R 	c #FDEF47",
-"S 	c #FEE551",
-"T 	c #FFF4C7",
-"U 	c #FEED99",
-"V 	c #FAF35D",
-"W 	c #FBF258",
-"X 	c #FDE851",
-"Y 	c #FCF24F",
-"Z 	c #FEE54B",
-"` 	c #FEEA43",
-" .	c #FFE46D",
-"..	c #FEE469",
-"+.	c #F9FA63",
-"@.	c #F9FB63",
-"#.	c #FAF85E",
-"$.	c #FAF85C",
-"%.	c #FBF056",
-"&.	c #FBF659",
-"*.	c #FBF454",
-"=.	c #FCF250",
-"-.	c #FCF14E",
-";.	c #FDF04B",
-">.	c #FDEF49",
-",.	c #FDEE46",
-"'.	c #FEED45",
-").	c #FEEC42",
-"!.	c #FEE258",
-"~.	c #FFFBEA",
-"{.	c #FDE561",
-"].	c #F9FB64",
-"^.	c #FAF75B",
-"/.	c #FAF559",
-"(.	c #FCF14F",
-"_.	c #F9E944",
-":.	c #FDE546",
-"<.	c #FFF0B2",
-"[.	c #FFF3C4",
-"}.	c #FBED5D",
-"|.	c #FDE54F",
-"1.	c #E8E250",
-"2.	c #C7C343",
-"3.	c #C7C143",
-"4.	c #CAC443",
-"5.	c #E5DD4A",
-"6.	c #D1C842",
-"7.	c #D2CA42",
-"8.	c #DAC13F",
-"9.	c #A39A31",
-"0.	c #FAED4A",
-"a.	c #A9A132",
-"b.	c #CEC23C",
-"c.	c #A39A2E",
-"d.	c #A89E2E",
-"e.	c #A79C2E",
-"f.	c #DBCC3B",
-"g.	c #FEE942",
-"h.	c #FEE884",
-"i.	c #FEEEA4",
-"j.	c #FBF35D",
-"k.	c #FCF256",
-"l.	c #EBE550",
-"m.	c #B8B33E",
-"n.	c #BBB63F",
-"o.	c #CDC744",
-"p.	c #DED647",
-"q.	c #C9C140",
-"r.	c #C4BC3D",
-"s.	c #DACF43",
-"t.	c #CFB83C",
-"u.	c #F5E948",
-"v.	c #DCD140",
-"w.	c #E5D842",
-"x.	c #EEE142",
-"y.	c #DED13E",
-"z.	c #ECDD40",
-"A.	c #FEE943",
-"B.	c #FEEA8F",
-"C.	c #FEEC96",
-"D.	c #FAF55F",
-"E.	c #FEE34E",
-"F.	c #EFE94F",
-"G.	c #989231",
-"H.	c #85802A",
-"I.	c #E8DE48",
-"J.	c #ECD445",
-"K.	c #67601F",
-"L.	c #F3E546",
-"M.	c #766F21",
-"N.	c #C5B936",
-"O.	c #625B1B",
-"P.	c #FEE546",
-"Q.	c #FFF0B1",
-"R.	c #FFF3BF",
-"S.	c #FBEE5F",
-"T.	c #F9FB65",
-"U.	c #D7D956",
-"V.	c #7A7B30",
-"W.	c #9D9E3D",
-"X.	c #77772E",
-"Y.	c #F0EE5A",
-"Z.	c #F6F45B",
-"`.	c #F0ED58",
-" +	c #E7D349",
-".+	c #C1BB42",
-"++	c #C7C244",
-"@+	c #AFAB3C",
-"#+	c #C5C042",
-"$+	c #9E9935",
-"%+	c #ADA738",
-"&+	c #7A7627",
-"*+	c #D3CB42",
-"=+	c #DAD144",
-"-+	c #9B932F",
-";+	c #9C942E",
-">+	c #C1B738",
-",+	c #BDB337",
-"'+	c #B3A933",
-")+	c #E5D73F",
-"!+	c #827923",
-"~+	c #BBAE32",
-"{+	c #FEEC43",
-"]+	c #FEE357",
-"^+	c #FFFAE7",
-"/+	c #FFFCF0",
-"(+	c #808132",
-"_+	c #A0A13E",
-":+	c #9B9A3B",
-"<+	c #E5E356",
-"[+	c #71702A",
-"}+	c #6D6C28",
-"|+	c #EEEB57",
-"1+	c #79772B",
-"2+	c #B5B13F",
-"3+	c #CAC546",
-"4+	c #817E2C",
-"5+	c #BFB940",
-"6+	c #CCC643",
-"7+	c #FCF352",
-"8+	c #7B7627",
-"9+	c #6F6A22",
-"0+	c #B0A534",
-"a+	c #716B21",
-"b+	c #E1D441",
-"c+	c #837C25",
-"d+	c #887F25",
-"e+	c #D6C739",
-"f+	c #FEE15F",
-"g+	c #FEE778",
-"h+	c #FAF762",
-"i+	c #8B8C37",
-"j+	c #D0D151",
-"k+	c #B1B044",
-"l+	c #BCBB48",
-"m+	c #8D8C34",
-"n+	c #78782C",
-"o+	c #ACAA3F",
-"p+	c #A2A03A",
-"q+	c #B4A63A",
-"r+	c #939033",
-"s+	c #D3CD48",
-"t+	c #56531D",
-"u+	c #D5CD45",
-"v+	c #57541C",
-"w+	c #B1AA38",
-"x+	c #B9B13A",
-"y+	c #D2BF3E",
-"z+	c #7F7525",
-"A+	c #B6AD35",
-"B+	c #C4B938",
-"C+	c #9E952C",
-"D+	c #BFB335",
-"E+	c #EBDC40",
-"F+	c #FEEA44",
-"G+	c #FCEA60",
-"H+	c #E8EB5D",
-"I+	c #6E6F2B",
-"J+	c #9A9B3C",
-"K+	c #96963A",
-"L+	c #C0C049",
-"M+	c #949437",
-"N+	c #A2A03B",
-"O+	c #9F9E3A",
-"P+	c #B1AE3F",
-"Q+	c #A99B35",
-"R+	c #B6AE3D",
-"S+	c #B3AF3D",
-"T+	c #9D9935",
-"U+	c #FBF554",
-"V+	c #FBF352",
-"W+	c #FCF24D",
-"X+	c #FEEB4B",
-"Y+	c #FEE74A",
-"Z+	c #FDF048",
-"`+	c #FEEE46",
-" @	c #FEEE45",
-".@	c #FEE845",
-"+@	c #FFEEA7",
-"@@	c #FEE260",
-"#@	c #F9FC64",
-"$@	c #F9FB61",
-"%@	c #FAF95D",
-"&@	c #FAF85B",
-"*@	c #FCEC52",
-"=@	c #F5E650",
-"-@	c #D2CE48",
-";@	c #FBF353",
-">@	c #FBF151",
-",@	c #FCEE4F",
-"'@	c #FCED4E",
-")@	c #FDEB4D",
-"!@	c #FCE84C",
-"~@	c #FDE550",
-"{@	c #FDE151",
-"]@	c #FDE559",
-"^@	c #FDE35A",
-"/@	c #FEE25B",
-"(@	c #FEE15B",
-"_@	c #FEE160",
-":@	c #FFF5CC",
-"<@	c #FEE983",
-"[@	c #FBF15B",
-"}@	c #FBF25B",
-"|@	c #FBF059",
-"1@	c #FBED5B",
-"2@	c #FBE95D",
-"3@	c #FCE95F",
-"4@	c #FCE760",
-"5@	c #FEE55E",
-"6@	c #FDE25E",
-"7@	c #FEE15D",
-"8@	c #FEE366",
-"9@	c #FEE673",
-"0@	c #FEED9D",
-"a@	c #FFEFAE",
-"b@	c #FFF7D6",
-"c@	c #FFFCEE",
-"d@	c #FFFEFB",
-"e@	c #FFF6D2",
-"f@	c #FEEC97",
-"g@	c #FFEFA7",
-"h@	c #FFF1B9",
-"i@	c #FFF4C5",
-"j@	c #FFFAE8",
-"                                                                ",
-"                                                                ",
-"                                                                ",
-"                                                                ",
-"                                                                ",
-"                                                                ",
-"                                                                ",
-"                                          . + @ # $ % & * =     ",
-"            - ; > , ' ) ! ~ { ] ^ / ( _ : < [ } | 1 2 3 4 5     ",
-"  6 / 7 8 9 0 a b c d e f g h i j k l m n o p q r s t u v w .   ",
-"  x y z A B C D E F G H I J K L M N O P n Q p q r R t u v S T   ",
-"  U V z A B C D W X G H I J K L M N Y Z n Q p q r R t u v `  .  ",
-"  ..+.@.A B C #.$.%.G &.I J K *.L N =.Y -.Q ;.p >.R ,.'.u ).!.~.",
-"+ {.].@.A B C #.$.^./.&.I J K *.L N =.(.Z Q ;.p >.R ,._.u ).:.<.",
-"[.}.].@.A B C #.$.W |.&.I 1.2.3.4.5.6.7.8.9.0.a.b.c.d.e.f.).g.h.",
-"i.j.].@.A B C #.$.^.|.k.I l.m.n.o.p.q.r.s.t.u.v.w.x.y.z.u ).A.B.",
-"C.D.].@.A B C #.$.^./.E.I J K *.F.G.H.H.I.J.K.p L.M.N.O.u ).P.Q.",
-"R.S.T.U.V.W.X.Y.Z.`.^. +.+++@+#+$+%+&+*+=+-+;+>+,+'+)+!+~+{+]+^+",
-"/+{.T.@.(+_+:+<+[+}+|+1+2+3+4+5+6+7+8+Y -.9+0+a+b+c+,.d+e+{+f+  ",
-"  g+h+].i+j+k+l+m+n+o+p+q+r+s+t+*.u+v+w+x+9+y+z+A+B+C+D+E+F+h.  ",
-"  = G+H+I+J+K+L+M+N+O+P+Q+R+S+T+U+V+N k Y W+X+Y+p Z+R `+ @.@+@  ",
-"    @@#@z $@B C %@$.&@G *@=@-@K ;@>@,@'@)@!@~@{@]@^@/@(@f+_@:@  ",
-"    <@[@}@|@1@2@3@4@5@6@/@7@8@/ 9@] { 0@a@) ' b@> c@d@          ",
-"    e@f@g@h@i@$ # j@+ .                                         ",
-"                                                                ",
-"                                                                ",
-"                                                                ",
-"                                                                ",
-"                                                                ",
-"                                                                ",
-"                                                                ",
-"                                                                "};
+static char *easytag[] = {
+/* columns rows colors chars-per-pixel */
+"32 32 171 2",
+"   c #22A322A30D4D",
+".  c #2C2C2C2C10D1",
+"X  c #3C523B66152B",
+"o  c #42823EFF13D4",
+"O  c #458542D81657",
+"+  c #42634263195A",
+"@  c #47C846C719DA",
+"#  c #51D24E8E19DA",
+"$  c #515151511F1F",
+"%  c #594456161C47",
+"&  c #5EDF5A9A1C9D",
+"*  c #60205CDD1EDF",
+"=  c #4CCD498924A5",
+"-  c #553554F42080",
+";  c #5C9C58D92D2D",
+":  c #549452123535",
+">  c #60205E9E22A3",
+",  c #65C564A424C5",
+"<  c #6BEC67A723E4",
+"1  c #6B6B6A2A2626",
+"2  c #6BEC6BAB28A9",
+"3  c #71316DEE24E5",
+"4  c #74B472322747",
+"5  c #7AFB75B62545",
+"6  c #75E674742A7A",
+"7  c #79B973732DEE",
+"8  c #6BEC682830F1",
+"9  c #77B773333777",
+"0  c #7ABB75F53C3C",
+"q  c #64E561A14444",
+"w  c #6E2E6A2A4404",
+"e  c #7A3A75754141",
+"r  c #82977E932AAA",
+"t  c #8A0A7DFE27A8",
+"y  c #850582E32ECF",
+"u  c #8C0C86062A80",
+"i  c #8FCF8B4B2D6D",
+"p  c #903B8A4A2BD6",
+"a  c #9BAB92422C0C",
+"s  c #90108DCD3232",
+"d  c #9ABA96E733C4",
+"f  c #90D0911138B9",
+"g  c #9DDD9B5B3939",
+"h  c #A262979729AA",
+"j  c #A7679E5E2F6F",
+"k  c #A9E99F9F2D2D",
+"l  c #A3239CFD33B3",
+"z  c #B0509D9E3313",
+"x  c #AE2EA1612BAC",
+"c  c #A707A12034D5",
+"v  c #AD4DA6863596",
+"b  c #A5C5A2823959",
+"n  c #ABC1A9543D3D",
+"m  c #B131A7E735B6",
+"M  c #BE0DA1513586",
+"N  c #BFFFA1E13979",
+"B  c #B070AC6C3BFC",
+"V  c #BD1DB37336D7",
+"C  c #B5F5B2073DD3",
+"Z  c #BA59B5953DDE",
+"A  c #C242B5753333",
+"S  c #C282B8B836F7",
+"D  c #C9C9B7373EFF",
+"F  c #C491BBFB3B3B",
+"G  c #CB0AB8B83D7D",
+"H  c #CFCFC1813575",
+"J  c #D9D9C7873777",
+"K  c #D817CACA3A7A",
+"L  c #DB1ACC8C3939",
+"P  c #DF3FD0F03BBC",
+"I  c #F373E1613CBD",
+"U  c #874781414404",
+"Y  c #96968FCF4D0D",
+"T  c #9B5B8FCF4D0D",
+"R  c #93138D0D5616",
+"E  c #9C5C94D45595",
+"W  c #A52595154343",
+"Q  c #A3029B5B4EAF",
+"!  c #A2229B1B5A9A",
+"~  c #A868A1214101",
+"^  c #AB4AAB0A40A0",
+"/  c #A9E9A2374D22",
+"(  c #AF6FAF6F4808",
+")  c #BA3AB6F640C1",
+"_  c #BC7CBA3A44C5",
+"`  c #B4B4AC6C5B1B",
+"'  c #B9B9B0F054D5",
+"]  c #B8B8B0705B9B",
+"[  c #BF7FBFFF5CDD",
+"{  c #C181B1F14ACB",
+"}  c #C040BDFD4888",
+"|  c #C7C7BE7E61E2",
+" . c #8000E2A25F1F",
+".. c #BEFEE0E05717",
+"X. c #CCECC5243FE0",
+"o. c #C545C4444949",
+"O. c #C9C9C1C147C8",
+"+. c #DC9CD2524141",
+"@. c #D656D4134CED",
+"#. c #DAFAD4344828",
+"$. c #CA4AC0C05191",
+"%. c #CDCDC4035B1B",
+"&. c #D9D9CECE5C9C",
+"*. c #D00FD0D05191",
+"=. c #DF1EDF1E5454",
+"-. c #E0E0C6464141",
+";. c #E1E1D6C14197",
+":. c #E464DADA4646",
+">. c #E363D8174949",
+",. c #FFFFD7974747",
+"<. c #F676D8D84545",
+"1. c #FF8ADC5146BC",
+"2. c #FFEDD74448AD",
+"3. c #F555DABA4868",
+"4. c #FEB7DC3D4AC4",
+"5. c #E767DB5B5B1B",
+"6. c #F5F5DF9F5B1B",
+"7. c #EE4EE1A142E3",
+"8. c #EF6FE3024A2A",
+"9. c #F7F7E3A34787",
+"0. c #FD2DE22144D4",
+"q. c #FD64EDD244AC",
+"w. c #F373E4134B6B",
+"e. c #FE68E52F4C57",
+"r. c #F55FEA954BB6",
+"t. c #FD38EDF64A86",
+"y. c #FC79F18F4C95",
+"u. c #E868E7265595",
+"i. c #ED2CEB405681",
+"p. c #E363E4235898",
+"a. c #EECEEECE5B3B",
+"s. c #F308E3CE53D4",
+"d. c #FE48E51A5292",
+"f. c #F525ED4D5232",
+"g. c #FCFCE9695555",
+"h. c #F5F5E1A15D1D",
+"j. c #FEBEE6865C7C",
+"k. c #FBE6EF995BB1",
+"l. c #FB8FF409534D",
+"z. c #F635F5B55E1E",
+"x. c #FB3AF5C75A1D",
+"c. c #FA0CF8C15D5D",
+"v. c #D454CA4A6424",
+"b. c #D918CE0D66E7",
+"n. c #E01FD4946525",
+"m. c #DEDEDF1E7474",
+"M. c #EA6ADE1D69A9",
+"N. c #FDCAE4F164E5",
+"B. c #FDE8EC3663EE",
+"V. c #F433E6666CAC",
+"C. c #F5F5EA096B8C",
+"Z. c #FD7DEE4E6C0C",
+"A. c #FBA1F64F6431",
+"S. c #FA29FA296242",
+"D. c #F6F6F4746AAA",
+"F. c #FD13F2A06B5A",
+"G. c #FBFBF8F86D83",
+"H. c #F635E8E870B0",
+"J. c #FC3BEDAD7535",
+"K. c #F676F0B07131",
+"L. c #FDFDF1B171F2",
+"P. c #FB1AF9F97515",
+"I. c #FAFAFA497CBC",
+"U. c #FD3CEFEF81C1",
+"Y. c #FAFAF77783C3",
+"T. c #FB0FFB018375",
+"R. c #FC3BF6358ACA",
+"E. c #FBABFC068C41",
+"W. c #FBC8FC95945B",
+"Q. c #FB5AFC9C9898",
+"!. c None",
+/* pixels */
+"!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.",
+"!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.",
+"!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.",
+"!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.",
+"!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.",
+"!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.",
+"!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.,.,.1.1.1.1.,.!.!.!.",
+"!.!.!.!.!.!.!.!.!.M 2.4.4.4.e.e.e.e.3.e.t.t.t.y.q.q.q.q.1.!.!.!.",
+"!.!.2.j.B.Z.F.F.N.F.G.A.A.x.l.l.l.l.w.t.y.y.y.t.t.q.q.q.0.!.!.!.",
+"!.!.4.E.W.E.E.T.V.L.G.A.A.x.l.l.l.l.w.e.y.y.y.t.q.q.q.q.q.,.!.!.",
+"!.!.d.Q.W.E.T.T.V.Z.G.A.x.l.l.l.l.l.r.e.y.y.y.t.q.q.q.q.q.0.!.!.",
+"!.!.J.Q.W.E.T.I.K.F.A.x.x.l.f.l.l.l.y.y.;.+.r.7.;.7.P A H J M !.",
+"!.N W.W.E.E.T.I.P.D.g s b Z r l.F F l m l V F u p a k a h x 1.!.",
+"!.N.Q.W.E.T.T.I.P.k.l d b Z d f.c d l a z F ;.S F K P L q.I 0.!.",
+"!.U.Q.W.E.T.I.P.S.f.D @.f.l.l.l.l.y.y.y.<.t.t.t.q.q.q.8.s.k.d.!.",
+"!.R.W.E.E.T.P.S.c.x.3.l.l.l.l.l.l.X.c a t 9.V j t.s.e Q q M.j.!.",
+"!.Y.E.m.[ ( ^ c.c.x.w.e.l.l.l.l.l.# p & u M 5 = k./ Q F.n.b.d.!.",
+"!.x.S.f + ^ - @.x.i.x.-.d C 4 Z % l X.% y.9.7 9 $.U ' F.` ! 4.!.",
+"!.g.S.*.- 6 a.u., , n < B r u l 5 y.:.O y.>.; 0 0 / Y F.| E ,.!.",
+"!.2.c.p.. $ u.i.n 1 y ) X X #.O r y.8.o y.~ { B.: &.w ] R T !.!.",
+"!.!.g.a.+ =.o.4 @ n 4 6 G % r.* v y.v + O.8 W 5./ %.C.v.H. .!.!.",
+"!.!.4.}   2 X _ > y 6 C z #.l.p w.y.l.l.x.x.6.B.A.F.F.L.L...!.!.",
+"!.!.!.s.z.c.c.c.x.x.x.l.3.l.3 i y.l.l.l.x.x.h.B.B.B.N.N.N.4.!.!.",
+"!.!.!.4.c.c.c.x.x.x.l.l.3.e.e.e.e.e.4.4.4.2.M !.!.!.!.!.!.!.!.!.",
+"!.!.!.2.d.d.e.4.4.2.2.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.",
+"!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.",
+"!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.",
+"!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.",
+"!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.",
+"!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.",
+"!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.",
+"!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!."
+};
only in patch2:
unchanged:
--- easytag-2.1.4.orig/debian/watch
+++ easytag-2.1.4/debian/watch
@@ -0,0 +1,2 @@
+version=3
+http://sf.net/easytag/easytag-([0-9.]*)\.tar\.bz2
only in patch2:
unchanged:
--- easytag-2.1.4.orig/debian/install
+++ easytag-2.1.4/debian/install
@@ -0,0 +1 @@
+debian/easytag.xpm usr/share/pixmaps
only in patch2:
unchanged:
--- easytag-2.1.4.orig/doc/easytag.1.in
+++ easytag-2.1.4/doc/easytag.1.in
@@ -1,6 +1,6 @@
 .TH EasyTAG 1
 .SH NAME
-EasyTAG @VERSION@ \- Tag editor for MP3 and Ogg Vorbis files
+EasyTAG \- Tag editor for MP3 and Ogg Vorbis files
 .SH SYNOPSIS
 .na
 .nh
